##########################################################
# Custom Font System 1.0
# Haxo Game Studios                
# System pozwalający wgrać własną czcionkę do projektu, bez konieczności jej instalacji
# do systemu operacyjnego Windows. 
#
# Autor: Dawid Maxymilian Tomaszewski
# Adres mailowy: haxogamestudios@gmail.com
# Skrypt przeznaczony dla silnika RPG Maker XP i RPG Maker XPAce
#
# Licencja użytkowania skryptu "Custom Font System 1.0"
# 1. Postanowienia ogólne
# Niniejsza licencja reguluje zasady korzystania ze skryptu Custom Font System w wersji 1.0, 
# dalej zwanego "skryptem". Użytkownik, który korzysta ze skryptu, zgadza się na warunki niniejszej licencji.
#
# 2. Zezwolenia
#   - Korzystanie ze skryptu zarówno w grach komercyjnych, jak i niekomercyjnych.
#   - Modyfikację kodu w celu dostosowania go do specyfiki projektu, pod warunkiem zachowania warunków licencji.
#
# 3. Ograniczenia
#   - Zakazuje się publikacji skryptu w tej lub zmodyfikowanej wersji na innych witrynach niż
#     https://www.rpgmaker.pl/. Można uzyskać taką zgodę jedynie pisząc do mnie o udzielenie licencji 
#     zezwalającej na publikację w innym miejscu niż Twierdza.
#   - Zakazuje się sprzedaży skryptu w jakiejkolwiek formie, zarówno oryginalnej, jak i zmodyfikowanej.
#
# 4. Informacja o autorze
# Każdy projekt korzystający ze skryptu Custom Font System 1.0 
# musi spełniać następujące warunki dotyczące uznania autorstwa:
#
# Podczas uruchamiania opcji "Nowa gra" należy wyświetlić poniższe informacje na ekranie przez
# minimum 7 sekund, pomijając czas przejścia efektów wizualnych, takich jak tzw. "smooth":
#
# [=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=]
#
# Nazwa: Custom Font System 1.0
# Autor: Dawid Maxymilian Tomaszewski
# Studio: Haxo Game Studios
# Witryna: https://www.rpgmaker.pl/
# YouTube: HaxoGameStudiosOfficial
#
# [=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=][=]
##########################################################

module FontManager
  FONT_PATH = "Fonts/"  # Path to the fonts folder

  AddFontResource = Win32API.new('gdi32', 'AddFontResourceA', ['P'], 'L')
  SendMessage = Win32API.new('user32', 'SendMessageA', ['L', 'L', 'L', 'L'], 'L')

  def self.load_font(file_name)
    font_path = FONT_PATH + file_name
    if File.exist?(font_path)
      result = AddFontResource.call(font_path)
      if result > 0
        SendMessage.call(0xFFFF, 0x001D, 0, 0)
        puts "Font #{file_name} loaded successfully!"
      else
        raise "Failed to load the font #{file_name}!"
      end
    else
      raise "Font file #{file_name} not found!"
    end
  end
end

# Load the font
FontManager.load_font("Minecraft_PL_Font.ttf")  # Make sure the path is correct

# Overwrite the default Font class to force the global font
class Font
  alias original_initialize initialize
  def initialize
    original_initialize
    self.name = "Minecraft PL Font"  # Default font name
    self.size = 32                   # Default font size
    self.bold = false                # Default disable bold
    self.italic = false              # Default no italic
  end

  class << self
    attr_accessor :default_name, :default_size, :default_bold, :default_italic
  end
end